==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebHeadSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescription } from "./WebHeadSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
export let WebHeadSelectorTemplateDetailsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebHeadSelectorTemplateDetailsDescriptionMetadata extends Base {
        static b(a) {
            if (WebHeadSelectorTemplateDetailsDescriptionMetadata.a == null) {
                WebHeadSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebHeadSelectorTemplateDetailsDescriptionMetadata.c(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
            }
            if (a.k(WebHeadSelectorTemplateDetailsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:HeadSelectorTemplateDetails");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("SelectedCount", "Number:double");
            a.item("TotalCount", "Number:double");
        }
        static d(a) {
            WebHeadSelectorTemplateDetailsDescriptionMetadata.b(a);
            a.ad("WebHeadSelectorTemplateDetails", () => new WebHeadSelectorTemplateDetailsDescription());
            a.ac("WebHeadSelectorTemplateDetails", WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
    }
    WebHeadSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebHeadSelectorTemplateDetailsDescriptionMetadata, 'WebHeadSelectorTemplateDetailsDescriptionMetadata');
    WebHeadSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateDetailsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebHeadSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescription } from "./WebHeadSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
export let WebHeadSelectorTemplateDetailsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebHeadSelectorTemplateDetailsDescriptionMetadata extends Base {
        static b(a) {
            if (WebHeadSelectorTemplateDetailsDescriptionMetadata.a == null) {
                WebHeadSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebHeadSelectorTemplateDetailsDescriptionMetadata.c(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
            }
            if (a.k(WebHeadSelectorTemplateDetailsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:HeadSelectorTemplateDetails");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("SelectedCount", "Number:double");
            a.item("TotalCount", "Number:double");
        }
        static d(a) {
            WebHeadSelectorTemplateDetailsDescriptionMetadata.b(a);
            a.ae("WebHeadSelectorTemplateDetails", () => new WebHeadSelectorTemplateDetailsDescription());
            a.ad("WebHeadSelectorTemplateDetails", WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
    }
    WebHeadSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebHeadSelectorTemplateDetailsDescriptionMetadata, 'WebHeadSelectorTemplateDetailsDescriptionMetadata');
    WebHeadSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateDetailsDescriptionMetadata;
})();
